pub struct Areas {
pub state: Area,
pub status: Area,
pub input: Area,
pub purpose: Option<Area>,
pub pos_idx: usize,
pub nb_pos: usize,
}Expand description
the areas of the various parts of a panel. It’s also where a state usually checks how many panels there are, and their respective positions
Fields
state: Areastatus: Areainput: Areapurpose: Option<Area>pos_idx: usizenb_pos: usizeImplementations
Sourceimpl Areas
impl Areas
Sourcepub fn create(
present_panels: &mut [Panel],
layout_instructions: &LayoutInstructions,
insertion_idx: usize,
screen: Screen,
with_preview: bool,
) -> Self
pub fn create( present_panels: &mut [Panel], layout_instructions: &LayoutInstructions, insertion_idx: usize, screen: Screen, with_preview: bool, ) -> Self
compute an area for a new panel which will be inserted
pub fn resize_all( panels: &mut [Panel], layout_instructions: &LayoutInstructions, screen: Screen, with_preview: bool, )
pub fn is_first(&self) -> bool
pub fn is_last(&self) -> bool