pub struct SearchModeMapEntry {
pub key: Option<String>,
pub mode: SearchMode,
}Expand description
define a mapping from a search mode which can be typed in the input to a SearchMode value
Fields
key: Option<String>mode: SearchModeImplementations