pub enum ProcessOutputKind {
File,
Dir,
Stdout,
}Expand description
Specifies how the output of the transformation is read:
- read from {output-path} if it’s in the command, or
- read from the first file found in {output-dir} if it’s in the command, or
- read from stdout if neither is in the command
Variants