pub struct ShellInstall {
pub should_quit: bool,
/* private fields */
}Fields
should_quit: boolImplementations
Sourceimpl ShellInstall
impl ShellInstall
pub fn new(force_install: bool) -> Self
Sourcepub fn print(shell: &str) -> Result<(), ProgramError>
pub fn print(shell: &str) -> Result<(), ProgramError>
write on stdout the script building the function for the given shell
Sourcepub fn check(&mut self) -> Result<(), ShellInstallError>
pub fn check(&mut self) -> Result<(), ShellInstallError>
check whether the shell function is installed an up to date, install it if it wasn’t refused before or if broot is launched with –install.
Sourcepub fn comment_error(&self, err: &ShellInstallError)
pub fn comment_error(&self, err: &ShellInstallError)
print some additional information on the error (typically before the error itself is dumped)
pub fn remove(&self, path: &Path) -> Result<(), ShellInstallError>